<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!--
COPYRIGHT NOTICE:
Copyright 2006 Center for Technology in Government.
The Center grants permission to use and modify this software code free of charge provided  
this copyright notice is included. By using this code you agree to indemnify the Center from 
any liability that might arise from its use. Selling the code is expressly forbidden.
-->
	<!-- *******************************************************************************************
                   COMMENT  Begin All Title Element Matches  below                       
      ******************************************************************************************* -->
	<xsl:template match="title">
		<span class="head1">
			<xsl:value-of select="."/>
			<br/>
		</span>
		</xsl:template>
	<xsl:template match="sect1/title">
		<div class="head2">
			<br/>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	<xsl:template match="para">
		<xsl:choose>
			<xsl:when test="@role='programlisting'">
				<div>
					<pre class="programcode">
						<xsl:apply-templates/>
					</pre>
				</div>
			</xsl:when>
			<xsl:when test="child::itemizedlist">
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:when test="child::orderedlist">
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:otherwise>
				<p>
					<xsl:apply-templates/>
				</p>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="emphasis">
		<xsl:choose>
			<xsl:when test="@role='italics'">
				<em>
					<xsl:apply-templates/>
				</em>
			</xsl:when>
			<xsl:when test="@role='bolditalics'">
				<strong>
					<em>
						<xsl:apply-templates/>
					</em>
				</strong>
			</xsl:when>
			<xsl:otherwise>
				<strong>
					<xsl:apply-templates/>
				</strong>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="ulink">
		<xsl:variable name="ref">
		    <xsl:choose>
							<xsl:when test="contains(@url,'http://')">
									  <xsl:value-of select="@url" />
								</xsl:when>
								<xsl:when test="contains(@url,'.zip')">
									  <xsl:value-of select="@url" />
								</xsl:when>
							<xsl:when test="contains(@url,'?')">
								<xsl:value-of select="concat(substring-before(@url,'?'),$extension,'?',substring-after(@url,'?'))"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="concat(@url,$extension)"/>
							</xsl:otherwise>
						</xsl:choose>
		</xsl:variable>
		<a href="{$ref}" accesskey="" tabindex="0">
			<xsl:apply-templates/>
		</a>
	</xsl:template>
	<xsl:template match="mediaobject/imageobject">
		<xsl:variable name="alt">
			<xsl:value-of select="ancestor::mediaobject/textobject/phrase"/>
		</xsl:variable>
		<xsl:variable name="caption">
			<xsl:value-of select="ancestor::mediaobject/caption/para"/>
		</xsl:variable>
		<xsl:for-each select="imagedata">
			<img src="{@fileref}" height="{@contentdepth}" width="{@contentwidth}" alt="{$alt}" style="float:{@align}; margin: 2px;"/>
			<xsl:if test="$caption!=''">
				<xsl:apply-templates select="ancestor::mediaobject/caption/para[role='caption']"/>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="textobject/phrase">
		<xsl:text> </xsl:text>
	</xsl:template>
	<xsl:template match="itemizedlist">
		<ul>
			<xsl:apply-templates/>
		</ul>
	</xsl:template>
	<xsl:template match="orderedlist">
		<ol>
			<xsl:apply-templates/>
			<xsl:text> </xsl:text>
		</ol>
	</xsl:template>
	<xsl:template match="entry/para/orderedlist">
		<div class="noindententry">
			<ol>
				<xsl:apply-templates/>
				<xsl:text> </xsl:text>
			</ol>
		</div>
	</xsl:template>
	<xsl:template match="simplelist">
		<dl>
			<dd>
				<xsl:apply-templates/>
			</dd>
		</dl>
	</xsl:template>
	<xsl:template match="member">
		<div class="normtext">
			<xsl:apply-templates/>
			<xsl:text> </xsl:text>
			<br/>
		</div>
	</xsl:template>
	<xsl:template match="simplelist/listitem">
		<dt class="normtext">
			<xsl:apply-templates/>
			<xsl:text> </xsl:text>
		</dt>
	</xsl:template>
	<xsl:template match="listitem">
		<li class="normtext">
			<xsl:apply-templates/>
		</li>
	</xsl:template>
	<xsl:template match="orderedlist/listitem">
		<xsl:choose>
			<xsl:when test="parent::orderedlist[@numeration='upperroman']">
				<li type="I" class="normtext">
					<xsl:apply-templates/>
				</li>
			</xsl:when>
			<xsl:when test="parent::orderedlist[@numeration='lowerroman']">
				<li type="i" class="normtext">
					<xsl:apply-templates/>
				</li>
			</xsl:when>
			<xsl:when test="parent::orderedlist[@numeration='upperalpha']">
				<li type="A" class="normtext">
					<xsl:apply-templates/>
				</li>
			</xsl:when>
			<xsl:when test="parent::orderedlist[@numeration='loweralpha']">
				<li type="a" class="normtext">
					<xsl:apply-templates/>
				</li>
			</xsl:when>
			<xsl:otherwise>
				<li class="normtext">
					<xsl:apply-templates/>
					<br/>
					<br/>
				</li>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="em|strong|br|pre|noscript">
		<xsl:copy>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="programlisting">
		<pre class="programcode">
			<xsl:apply-templates/>
		</pre>
	</xsl:template>
</xsl:stylesheet>
